/// <reference types="hapi__joi" />
import type { IDynamoQueryParamOptions, IDynamoQuerySecondaryParamOptions, ISecondaryIndexDef, IFieldCondition } from "../types";
import { DynamoDB } from "aws-sdk";
import { DocumentClient } from "aws-sdk/clients/dynamodb";
import Joi from "@hapi/joi";
import BaseMixins from "../core/base-mixins";
interface IDynamoOptions<T> {
    dynamoDb: () => DynamoDB;
    schemaDef: Joi.SchemaMap;
    dynamoDbClient: () => DocumentClient;
    dataKeyGenerator: () => string;
    featurePartitionValue: string;
    secondaryIndexOptions: ISecondaryIndexDef<T>[];
    baseTableName: string;
    strictRequiredFields: (keyof T)[] | string[];
}
export declare abstract class DynamoDataOperation<T> extends BaseMixins {
    #private;
    constructor({ dynamoDb, schemaDef, dynamoDbClient, secondaryIndexOptions, featurePartitionValue, baseTableName, strictRequiredFields, dataKeyGenerator, }: IDynamoOptions<T>);
    private _dynamoDbClient;
    private _dynamoDb;
    private generateDynamoTableKey;
    private _getLocalVariables;
    private _getBaseObject;
    private _checkValidateMustBeAnObjectDataType;
    private _checkValidateStrictRequiredFields;
    protected allCreateOneBase({ data }: {
        data: T;
    }): Promise<T>;
    private withConditionPassed;
    protected allGetOneByIdBase({ dataId, withCondition, }: {
        dataId: string;
        withCondition?: IFieldCondition<T>;
    }): Promise<T | null>;
    protected allGetOneByIdProjectBase<TExpectedVals = T>({ dataId, projectionAttributes, withCondition, }: {
        dataId: string;
        projectionAttributes: (keyof TExpectedVals)[];
        withCondition?: IFieldCondition<T>;
    }): Promise<any>;
    protected allUpdateOneDirectBase({ data }: {
        data: T;
    }): Promise<T>;
    protected allUpdateOneByIdBase({ dataId, data, withCondition, }: {
        dataId: string;
        data: T;
        withCondition?: IFieldCondition<T>;
    }): Promise<T>;
    private _allHelpValidateMarshallAndGetValue;
    protected allGetListOfTablesNamesOnlineBase(): Promise<DynamoDB.TableNameList | undefined>;
    protected allTableSettingUpdateTTLBase({ attrName, isEnabled, }: {
        attrName: keyof T;
        isEnabled: boolean;
    }): Promise<DynamoDB.TimeToLiveSpecification | null>;
    protected allGetTableInfoBase(): Promise<DynamoDB.TableDescription | null>;
    protected allCheckTableExistsBase(): Promise<boolean>;
    protected allCreateTableIfNotExistsBase(): Promise<DynamoDB.TableDescription | null>;
    protected allCreateTableBase(): Promise<DynamoDB.TableDescription | null>;
    protected allDeleteGlobalSecondaryIndexBase(indexName: string): Promise<DynamoDB.TableDescription | null>;
    protected allExistsByIdBase(dataId: string): Promise<boolean>;
    private _getGlobalSecondaryIndexCreationParams;
    private _allUpdateGlobalSecondaryIndexBase;
    protected allQueryBySecondaryIndexBase<T>({ keyQueryEquals: { keyFieldName, value }, secondaryIndexName, orderDesc, sortKeyQueryOptions, }: {
        keyQueryEquals: {
            keyFieldName: keyof T;
            value: string | number;
        };
        secondaryIndexName: string;
        orderDesc?: boolean;
        sortKeyQueryOptions?: IDynamoQuerySecondaryParamOptions<T>;
    }): Promise<T[]>;
    protected allQueryGetManyByConditionBase(paramOptions: IDynamoQueryParamOptions<T>): Promise<T[]>;
    protected allQueryGetManyByConditionPaginateBase(paramOptions: IDynamoQueryParamOptions<T>): Promise<import("../types").IDynamoPagingResult<T[]>>;
    protected allBatchGetManyByHashAndSortKey({ dataIds, fields, }: {
        dataIds: string[];
        fields?: (keyof T)[];
    }): Promise<T[]>;
    protected allQueryBySecondaryIndexPaginateBase<T>({ keyQueryEquals: { keyFieldName, value }, secondaryIndexName, orderDesc, sortKeyQueryOptions, }: {
        keyQueryEquals: {
            keyFieldName: keyof T;
            value: string | number;
        };
        secondaryIndexName: string;
        orderDesc?: boolean;
        sortKeyQueryOptions?: IDynamoQuerySecondaryParamOptions<T>;
    }): Promise<import("../types").IDynamoPagingResult<T[]>>;
    protected allDeleteByIdBase({ dataId, }: {
        dataId: string;
    }): Promise<T>;
    protected allDeleteManyDangerouselyByIds({ dataIds, }: {
        dataIds: string[];
    }): Promise<boolean>;
}
export {};
